==> example42-foreman-2.0.11.tar.gz: example42-foreman-2.0.11/spec/classes/foreman_spec.rb <==
require "#{File.join(File.dirname(__FILE__),'..','spec_helper.rb')}"

describe 'foreman' do

  let(:title) { 'foreman' }
  let(:node) { 'rspec.example42.com' }
  let(:facts) { { :ipaddress => '10.42.42.42', :operatingsystem => 'Debian' } }

  describe 'Test standard installation' do
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('absent') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
  end

  describe 'Test passenger installation' do
    let(:params) { {:passenger => true } }
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('absent') }
    it { should contain_service('foreman').with_ensure('stopped') }
    it { should contain_service('foreman').with_enable('false') }
    it { should contain_file('settings.yaml').with_ensure('present') }
  end

  describe 'Test provisioning installation' do
    let(:params) { {:unattended => true, :absent => false } }
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('present') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
  end

  describe 'Test installation of a specific version' do
    let(:params) { {:version => '1.0.42' } }
    it { should contain_package('foreman').with_ensure('1.0.42') }
  end

  describe 'Test standard installation with monitoring and firewalling' do
    let(:params) { {:monitor => true , :firewall => true, :port => '42', :protocol => 'tcp' } }

    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should monitor the process' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == true
    end
    it 'should place a firewall rule' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:enable]
      content.should == true
    end
  end

  describe 'Test decommissioning - absent' do
    let(:params) { {:absent => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }

    it 'should remove Package[foreman]' do should contain_package('foreman').with_ensure('absent') end 
    it 'should stop Service[foreman]' do should contain_service('foreman').with_ensure('stopped') end
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it 'should remove foreman configuration file' do should contain_file('settings.yaml').with_ensure('absent') end
    it 'should not monitor the process' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == false
    end
    it 'should remove a firewall rule' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:enable]
      content.should == false
    end
  end

  describe 'Test decommissioning - disable' do
    let(:params) { {:disable => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }

    it { should contain_package('foreman').with_ensure('present') }
    it 'should stop Service[foreman]' do should contain_service('foreman').with_ensure('stopped') end
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should not monitor the process' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == false
    end
    it 'should remove a firewall rule' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:enable]
      content.should == false
    end
  end

  describe 'Test decommissioning - disableboot' do
    let(:params) { {:disableboot => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }
  
    it { should contain_package('foreman').with_ensure('present') }
    it { should_not contain_service('foreman').with_ensure('present') }
    it { should_not contain_service('foreman').with_ensure('absent') }
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should not monitor the process locally' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == false
    end
    it 'should keep a firewall rule' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:enable]
      content.should == true
    end
  end 

  describe 'Test customizations - template' do
    let(:params) { {:template => "foreman/spec.erb" , :options => { 'opt_a' => 'value_a' } } }

    it 'should generate a valid template' do
      content = catalogue.resource('file', 'settings.yaml').send(:parameters)[:content]
      content.should match "fqdn: rspec.example42.com"
    end
    it 'should generate a template that uses custom options' do
      content = catalogue.resource('file', 'settings.yaml').send(:parameters)[:content]
      content.should match "value_a"
    end

  end

  describe 'Test customizations - source' do
    let(:params) { {:source => "puppet://modules/foreman/spec" , :source_dir => "puppet://modules/foreman/dir/spec" , :source_dir_purge => true } }

    it 'should request a valid source ' do
      content = catalogue.resource('file', 'settings.yaml').send(:parameters)[:source]
      content.should == "puppet://modules/foreman/spec"
    end
    it 'should request a valid source dir' do
      content = catalogue.resource('file', 'foreman.dir').send(:parameters)[:source]
      content.should == "puppet://modules/foreman/dir/spec"
    end
    it 'should purge source dir if source_dir_purge is true' do
      content = catalogue.resource('file', 'foreman.dir').send(:parameters)[:purge]
      content.should == true
    end
  end

  describe 'Test customizations - custom class' do
    let(:params) { {:my_class => "foreman::spec" } }
    it 'should automatically include a custom class' do
      content = catalogue.resource('file', 'settings.yaml').send(:parameters)[:content]
      content.should match "fqdn: rspec.example42.com"
    end
  end

  describe 'Test service autorestart' do
    it { should contain_file('settings.yaml').with_notify('Service[foreman]') }
  end

  describe 'Test service autorestart' do
    let(:params) { {:service_autorestart => "no" } }

    it 'should not automatically restart the service, when service_autorestart => false' do
      content = catalogue.resource('file', 'settings.yaml').send(:parameters)[:notify]
      content.should be_nil
    end
  end

  describe 'Test Puppi Integration' do
    let(:params) { {:puppi => true, :puppi_helper => "myhelper"} }

    it 'should generate a puppi::ze define' do
      content = catalogue.resource('puppi::ze', 'foreman').send(:parameters)[:helper]
      content.should == "myhelper"
    end
  end

  describe 'Test Monitoring Tools Integration' do
    let(:params) { {:monitor => true, :monitor_tool => "puppi" } }

    it 'should generate monitor defines' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:tool]
      content.should == "puppi"
    end
  end

  describe 'Test Firewall Tools Integration' do
    let(:params) { {:firewall => true, :firewall_tool => "iptables" , :protocol => "tcp" , :port => "42" } }

    it 'should generate correct firewall define' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:tool]
      content.should == "iptables"
    end
  end

  describe 'Test OldGen Module Set Integration' do
    let(:params) { {:monitor => "yes" , :monitor_tool => "puppi" , :firewall => "yes" , :firewall_tool => "iptables" , :puppi => "yes" , :port => "42" , :protocol => 'tcp' } }

    it 'should generate monitor resources' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:tool]
      content.should == "puppi"
    end
    it 'should generate firewall resources' do
      content = catalogue.resource('firewall', 'foreman_tcp_42').send(:parameters)[:tool]
      content.should == "iptables"
    end
    it 'should generate puppi resources ' do 
      content = catalogue.resource('puppi::ze', 'foreman').send(:parameters)[:ensure]
      content.should == "present"
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian' } }
    let(:params) { { :port => '42' } }

    it 'should honour top scope global vars' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == true
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :foreman_monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian' } }
    let(:params) { { :port => '42' } }

    it 'should honour module specific vars' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == true
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => false , :foreman_monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian' } }
    let(:params) { { :port => '42' } }

    it 'should honour top scope module specific over global vars' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == true
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => false , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian' } }
    let(:params) { { :monitor => true , :firewall => true, :port => '42' } }

    it 'should honour passed params over global vars' do
      content = catalogue.resource('monitor::process', 'foreman_process').send(:parameters)[:enable]
      content.should == true
    end
  end

end

==> example42-foreman-2.0.15.tar.gz: example42-foreman-2.0.15/spec/classes/foreman_spec.rb <==
require "#{File.join(File.dirname(__FILE__),'..','spec_helper.rb')}"

describe 'foreman' do

  let(:title) { 'foreman' }
  let(:node) { 'rspec.example42.com' }
  let(:facts) { { :ipaddress => '10.42.42.42', :operatingsystem => 'Debian', :operatingsystemrelease => '6.6' } }

  describe 'Test standard installation' do
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('absent') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
  end

  describe 'Test passenger installation' do
    let(:params) { {:passenger => true } }
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('absent') }
    it { should contain_service('foreman').with_ensure('stopped') }
    it { should contain_service('foreman').with_enable('false') }
    it { should contain_file('settings.yaml').with_ensure('present') }
    it { should contain_apache__vhost('foreman').with_ssl('true') }
    it { should contain_apache__vhost('foreman').with_port('443') }
  end

  describe 'Test passenger installation with SSL' do
    let(:params) { {
      :passenger => true,
      :ssl       => 'no',
    } }

    it { should contain_apache__vhost('foreman').with_ssl('false') }
    it { should contain_apache__vhost('foreman').with_port('80') }
  end

  describe 'Test provisioning installation' do
    let(:params) { {:unattended => true, :absent => false } }
    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_package('foreman-libvirt').with_ensure('present') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
  end

  describe 'Test installation of a specific version' do
    let(:params) { {:version => '1.0.42' } }
    it { should contain_package('foreman').with_ensure('1.0.42') }
  end

  describe 'Test standard installation with monitoring and firewalling' do
    let(:params) { {:monitor => true , :firewall => true, :port => '42', :protocol => 'tcp' } }

    it { should contain_package('foreman').with_ensure('present') }
    it { should contain_service('foreman').with_ensure('running') }
    it { should contain_service('foreman').with_enable('true') }
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should monitor the process' do
      should contain_monitor__process('foreman_process').with_enable(true)
    end
    it 'should place a firewall rule' do
      should contain_firewall('foreman_tcp_42').with_enable(true)
    end
  end

  describe 'Test decommissioning - absent' do
    let(:params) { {:absent => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }

    it 'should remove Package[foreman]' do should contain_package('foreman').with_ensure('absent') end
    it 'should stop Service[foreman]' do should contain_service('foreman').with_ensure('stopped') end
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it 'should remove foreman configuration file' do should contain_file('settings.yaml').with_ensure('absent') end
    it 'should not monitor the process' do
      should contain_monitor__process('foreman_process').with_enable(false)
    end
    it 'should remove a firewall rule' do
      should contain_firewall('foreman_tcp_42').with_enable(false)
    end
  end

  describe 'Test decommissioning - disable' do
    let(:params) { {:disable => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }

    it { should contain_package('foreman').with_ensure('present') }
    it 'should stop Service[foreman]' do should contain_service('foreman').with_ensure('stopped') end
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should not monitor the process' do
      should contain_monitor__process('foreman_process').with_enable(false)
    end
    it 'should remove a firewall rule' do
      should contain_firewall('foreman_tcp_42').with_enable(false)
    end
  end

  describe 'Test decommissioning - disableboot' do
    let(:params) { {:disableboot => true, :monitor => true , :firewall => true, :port => '42', :protocol => 'tcp'} }

    it { should contain_package('foreman').with_ensure('present') }
    it { should_not contain_service('foreman').with_ensure('present') }
    it { should_not contain_service('foreman').with_ensure('absent') }
    it 'should not enable at boot Service[foreman]' do should contain_service('foreman').with_enable('false') end
    it { should contain_file('settings.yaml').with_ensure('present') }
    it 'should not monitor the process locally' do
      should contain_monitor__process('foreman_process').with_enable(false)
    end
    it 'should keep a firewall rule' do
      should contain_firewall('foreman_tcp_42').with_enable(true)
    end
  end

  describe 'Test customizations - template' do
    let(:params) { {:template => "foreman/spec.erb" , :options => { 'opt_a' => 'value_a' } } }

    it 'should generate a valid template' do
      should contain_file('settings.yaml').with_content(/fqdn: rspec.example42.com/)
    end
    it 'should generate a template that uses custom options' do
      should contain_file('settings.yaml').with_content(/value_a/)
    end

  end

  describe 'Test customizations - source' do
    let(:params) { {:source => "puppet://modules/foreman/spec" , :source_dir => "puppet://modules/foreman/dir/spec" , :source_dir_purge => true } }

    it 'should request a valid source ' do
      should contain_file('settings.yaml').with_source("puppet://modules/foreman/spec")
    end
    it 'should request a valid source dir' do
      should contain_file('foreman.dir').with_source("puppet://modules/foreman/dir/spec")
    end
    it 'should purge source dir if source_dir_purge is true' do
      should contain_file('foreman.dir').with_purge(true)
    end
  end

  describe 'Test customizations - custom class' do
    let(:params) { {:my_class => "foreman::spec" } }
    it 'should automatically include a custom class' do
      should contain_file('settings.yaml').with_content(/fqdn: rspec.example42.com/)
    end
  end

  describe 'Test service autorestart' do
    it { should contain_file('settings.yaml').with_notify('Service[foreman]') }
  end

  describe 'Test service autorestart' do
    let(:params) { {:service_autorestart => "no" } }

    it 'should not automatically restart the service, when service_autorestart => false' do
      should contain_file('settings.yaml').with_notify(nil)
    end
  end

  describe 'Test Puppi Integration' do
    let(:params) { {:puppi => true, :puppi_helper => "myhelper"} }

    it 'should generate a puppi::ze define' do
      should contain_puppi__ze('foreman').with_helper("myhelper")
    end
  end

  describe 'Test Monitoring Tools Integration' do
    let(:params) { {:monitor => true, :monitor_tool => "puppi" } }

    it 'should generate monitor defines' do
      should contain_monitor__process('foreman_process').with_tool("puppi")
    end
  end

  describe 'Test Firewall Tools Integration' do
    let(:params) { {:firewall => true, :firewall_tool => "iptables" , :protocol => "tcp" , :port => "42" } }

    it 'should generate correct firewall define' do
      should contain_firewall('foreman_tcp_42').with_tool("iptables")
    end
  end

  describe 'Test OldGen Module Set Integration' do
    let(:params) { {:monitor => "yes" , :monitor_tool => "puppi" , :firewall => "yes" , :firewall_tool => "iptables" , :puppi => "yes" , :port => "42" , :protocol => 'tcp' } }

    it 'should generate monitor resources' do
      should contain_monitor__process('foreman_process').with_tool("puppi")
    end
    it 'should generate firewall resources' do
      should contain_firewall('foreman_tcp_42').with_tool("iptables")
    end
    it 'should generate puppi resources ' do
      should contain_puppi__ze('foreman').with_ensure("present")
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian', :operatingsystemrelease => '6.6' } }
    let(:params) { { :port => '42' } }

    it 'should honour top scope global vars' do
      should contain_monitor__process('foreman_process').with_enable(true)
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :foreman_monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian', :operatingsystemrelease => '6.6' } }
    let(:params) { { :port => '42' } }

    it 'should honour module specific vars' do
      should contain_monitor__process('foreman_process').with_enable(true)
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => false , :foreman_monitor => true , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian', :operatingsystemrelease => '6.6' } }
    let(:params) { { :port => '42' } }

    it 'should honour top scope module specific over global vars' do
      should contain_monitor__process('foreman_process').with_enable(true)
    end
  end

  describe 'Test params lookup' do
    let(:facts) { { :monitor => false , :ipaddress => '10.42.42.42' , :operatingsystem => 'Debian', :operatingsystemrelease => '6.6' } }
    let(:params) { { :monitor => true , :firewall => true, :port => '42' } }

    it 'should honour passed params over global vars' do
      should contain_monitor__process('foreman_process').with_enable(true)
    end
  end

end
